@@ -1,10 +1,10 @@
-""" Module of the YooniK BiometricInThings API.
+""" Module of the Youverse BiometricInThings API.
 """
 from enum import Enum
 from yk_utils.images import parse_image
 from yk_utils.apis import request, YoonikApiException
-from yk_bit.models import CaptureRequest, VerifyImagesRequest, VerifyRequest, \
-    CaptureResponse, VerifyResponse, VerifyImagesResponse
+from yk_bit_api_models import CaptureRequest, VerifyImagesRequest, VerifyRequest, \
+    CaptureResponse, VerifyResponse, VerifyImagesResponse, HardwareResetResponse
 
 
 class BiTStatus(Enum):
@@ -91,6 +91,21 @@ def verify_images(probe_image, reference_image, matching_score_threshold: float
     return VerifyImagesResponse.from_dict(response)
 
 
+def hardware_reset() -> HardwareResetResponse:
+    """ Performs camera hardware reset.
+    :return:
+        The hardware reset response.
+    """
+    url = 'bit/hardware_reset'
+    try:
+        response = request('POST', url)
+    except YoonikApiException as yk_exc:
+        if yk_exc.status_code == 501:
+            return HardwareResetResponse(message="Hardware reset not implemented "
+                                                 "for the installed camera type.")
+    return HardwareResetResponse.from_dict(response)
+
+
 def status() -> BiTStatus:
     """ Checks for the camera status. """
     url = 'bit/status'
