@@ -1,10 +1,10 @@
-""" Utilities for the Python SDK of the YooniK BiometricInThings API.
+""" Utilities for the Python SDK of the Youverse BiometricInThings API.
 """
 import yk_utils.apis
 
 
 class Key:
-    """Manage YooniK BiometricInThings API Subscription Key."""
+    """Manage Youverse BiometricInThings API Subscription Key."""
     @classmethod
     def set(cls, key: str):
         """Set the Subscription Key.
@@ -15,7 +15,7 @@ class Key:
 
 
 class BaseUrl:
-    """Manage YooniK BiometricInThings API Base URL."""
+    """Manage Youverse BiometricInThings API Base URL."""
     @classmethod
     def set(cls, base_url: str):
         yk_utils.apis.BaseUrl.set(base_url)
